In this directory, you will find several different example files for different purposes.

- create_model_condfiguration.py: this example, create a configuration file, you can edit this configuration and then use it for the actual simulation such as in the run_simulation.py

- run_simulation.py: this example uses a configuration file to run a simulation